ConnectivityMonitor class
ConnectivityMonitor is a widget that adapts its UI based on network status.
This widget listens to network changes via ConnectivityService
and provides customizable options for disconnected states.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ConnectivityMonitor
Constructors
- ConnectivityMonitor({Key? key, required Widget child, bool requiresConnection = true, bool useDialogAsConnectivityIndicator = true, bool useWidgetAsConnectivityIndicator = false, Widget? customDisconnectedWidget, Function? onConnected, Function? onDisconnected, Widget? customDialog, Widget? connectivityLoadingWidget})
-
const
Properties
- child → Widget
-
final
- connectivityLoadingWidget → Widget?
-
final
- customDialog → Widget?
-
final
- customDisconnectedWidget → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onConnected → Function?
-
final
- onDisconnected → Function?
-
final
- requiresConnection → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useDialogAsConnectivityIndicator → bool
-
final
- useWidgetAsConnectivityIndicator → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ConnectivityMonitor> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited